@@ -217,8 +217,6 @@ eog_full_screen_hide (GtkWidget *widget)
 	}
 
 	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, hide, (widget));
-
-	gtk_widget_destroy (widget);
 }
 
 static void
@@ -443,14 +441,21 @@ static void
 eog_full_screen_instance_init (EogFullScreen *fs)
 {
 	EogFullScreenPrivate *priv;
+	GdkScreen *screen;
+	GdkRectangle geometry;
+	int monitor;
 
 	priv = g_new0 (EogFullScreenPrivate, 1);
 	fs->priv = priv;
 
+	screen = gtk_window_get_screen (GTK_WINDOW (fs));
+	monitor = gdk_screen_get_monitor_at_window (screen, GTK_WIDGET (fs)->window);
+	gdk_screen_get_monitor_geometry (screen, monitor, &geometry);
+
 	gtk_window_set_default_size (GTK_WINDOW (fs),
-				     gdk_screen_width (),
-				     gdk_screen_height ()); 
-	gtk_window_move (GTK_WINDOW (fs), 0, 0);
+				     geometry.width,
+				     geometry.height);
+	gtk_window_move (GTK_WINDOW (fs), geometry.x, geometry.y);
 
 	priv->loop = TRUE;
 	priv->first_iter = NULL;
@@ -571,22 +576,24 @@ prepare_data (EogFullScreen *fs, EogImageList *image_list, EogImage *start_image
 	priv->list = g_object_ref (image_list);
 	priv->current = NULL;
 
+	/* determine first image to show */
+	if (start_image != NULL) 
+		priv->current = eog_image_list_get_iter_by_img (image_list, start_image);
+	
+	if (priv->current == NULL) 
+		priv->current = eog_image_list_get_first_iter (image_list);
+
+	/* special case if we only have one image */
 	if (eog_image_list_length (image_list) == 1) {
 		EogImage *single_image;
-		single_image = eog_image_list_get_img_by_pos (image_list, 0);
+		single_image = eog_image_list_get_img_by_iter (image_list, priv->current);
 		eog_scroll_view_set_image (EOG_SCROLL_VIEW (priv->view), 
 					   single_image);
 		g_object_unref (single_image);
+		priv->switch_timeout = 0; /* disable automatic switching always */
 	}
 	else {
-		/* determine first image to show */
 		priv->direction = EOG_DIRECTION_FORWARD;
-		if (start_image != NULL) 
-			priv->current = eog_image_list_get_iter_by_img (image_list, start_image);
-		
-		if (priv->current == NULL) 
-			priv->current = eog_image_list_get_first_iter (image_list);
-
 		priv->first_iter = eog_image_list_iter_copy (image_list, priv->current);
 		priv->first_image = TRUE;
 		prepare_load_image (fs, priv->current);
@@ -598,7 +605,7 @@ eog_full_screen_new (EogImageList *image_list, EogImage *start_image)
 {
 	EogFullScreen *fs;
 	EogFullScreenPrivate *priv;
-	GtkWidget     *widget;
+ 	GtkWidget     *widget;
 	GtkStyle      *style;
 	GConfClient   *client;
 	gboolean       upscale = TRUE;
@@ -653,3 +660,18 @@ eog_full_screen_enable_SunF36 (void)
 {
 	return (XKeysymToKeycode (GDK_DISPLAY (), SunXK_F36) != 0);
 }
+
+EogImage*  
+eog_full_screen_get_last_image (EogFullScreen *fs)
+{
+	EogFullScreenPrivate *priv;
+	EogImage *image;
+
+	g_return_val_if_fail (EOG_IS_FULL_SCREEN (fs), NULL);
+	
+	priv = fs->priv;
+
+	image = eog_image_list_get_img_by_iter (priv->list, priv->current);
+
+	return image;
+}
